on-and-on.cron

Cron expression parsing using cron-utils (Quartz flavor). Supports second-level precision with 7-field expressions.

Cron expression parsing using cron-utils (Quartz flavor).
Supports second-level precision with 7-field expressions.
raw docstring

descriptorclj


execution-interval-in-secondsclj

(execution-interval-in-seconds now parsed)

Calculates the interval in seconds between consecutive executions. Uses next two executions to avoid a cronutils bug with 0th-second truncation.

Calculates the interval in seconds between consecutive executions.
Uses next two executions to avoid a cronutils bug with 0th-second truncation.
raw docstring

explainclj

(explain parsed)

Returns a human-readable description of a parsed cron expression.

Returns a human-readable description of a parsed cron expression.
raw docstring

matches-schedule?clj

(matches-schedule? now parsed)

Returns true if the given instant matches the cron schedule.

Returns true if the given instant matches the cron schedule.
raw docstring

next-executionclj

(next-execution now parsed)

Returns the next execution instant after the given time.

Returns the next execution instant after the given time.
raw docstring

next-execution-in-secondsclj

(next-execution-in-seconds now parsed)

Returns the number of seconds until the next execution. Returns 0 if current time matches the schedule.

Returns the number of seconds until the next execution.
Returns 0 if current time matches the schedule.
raw docstring

parseclj

(parse expr)

Parses a Quartz cron expression string into a Cron object.

Parses a Quartz cron expression string into a Cron object.
raw docstring

parserclj

cljdoc builds & hosts documentation for Clojure/Script libraries