Cron expression parsing using cron-utils (Quartz flavor). Supports second-level precision with 7-field expressions.
Cron expression parsing using cron-utils (Quartz flavor). Supports second-level precision with 7-field expressions.
(execution-interval-in-seconds now parsed)Calculates the interval in seconds between consecutive executions. Uses next two executions to avoid a cronutils bug with 0th-second truncation.
Calculates the interval in seconds between consecutive executions. Uses next two executions to avoid a cronutils bug with 0th-second truncation.
(explain parsed)Returns a human-readable description of a parsed cron expression.
Returns a human-readable description of a parsed cron expression.
(matches-schedule? now parsed)Returns true if the given instant matches the cron schedule.
Returns true if the given instant matches the cron schedule.
(next-execution now parsed)Returns the next execution instant after the given time.
Returns the next execution instant after the given time.
(next-execution-in-seconds now parsed)Returns the number of seconds until the next execution. Returns 0 if current time matches the schedule.
Returns the number of seconds until the next execution. Returns 0 if current time matches the schedule.
(parse expr)Parses a Quartz cron expression string into a Cron object.
Parses a Quartz cron expression string into a Cron object.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |