Core scheduler pool management. Provides fixed-rate and cron-based task scheduling on top of CronScheduler.
Core scheduler pool management. Provides fixed-rate and cron-based task scheduling on top of CronScheduler.
(make-scheduler-pool {:keys [name]})Creates a new scheduler pool for running recurring tasks. Uses a 5-minute wall clock resync interval (recommended for server-side use).
Creates a new scheduler pool for running recurring tasks. Uses a 5-minute wall clock resync interval (recommended for server-side use).
(schedule-cron-task pool {:keys [name handler schedule]})Schedules a task using a Quartz cron expression. Uses SECONDS unit for precision with cron schedules. If calculated delay is 0, uses 1s to avoid a double-fire bug.
Schedules a task using a Quartz cron expression. Uses SECONDS unit for precision with cron schedules. If calculated delay is 0, uses 1s to avoid a double-fire bug.
(schedule-task pool {:keys [handler period-ms delay-ms mode] :or {delay-ms 0}})Schedules a recurring task running approximately every period-ms milliseconds.
The underlying CronScheduler compensates for clock drift.
Schedules a recurring task running approximately every `period-ms` milliseconds. The underlying CronScheduler compensates for clock drift.
(scheduler-pool? thing)Returns true if thing is a CronScheduler instance.
Returns true if thing is a CronScheduler instance.
(shutdown-scheduler-pool pool)Shuts down a scheduler pool, waiting up to 10s for tasks to complete. Falls back to shutdownNow if the timeout is exceeded.
Shuts down a scheduler pool, waiting up to 10s for tasks to complete. Falls back to shutdownNow if the timeout is exceeded.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |